@@ -12,8 +12,8 @@ describe 'postgresql::server', :type => :class do
   end
 
   describe 'with no parameters' do
-    it { should include_class("postgresql::params") }
-    it { should include_class("postgresql::server") }
+    it { should contain_class("postgresql::params") }
+    it { should contain_class("postgresql::server") }
     it 'should validate connection' do
       should contain_postgresql__validate_db_connection('validate_service_is_running')
     end
@@ -37,6 +37,7 @@ describe 'postgresql::server', :type => :class do
       {
         :ensure => 'absent',
         :datadir => '/my/path',
+        :xlogdir => '/xlog/path',
       }
     end
 
@@ -57,6 +58,12 @@ describe 'postgresql::server', :type => :class do
         :ensure => 'absent',
       })
     end
+
+    it 'should remove xlogdir' do
+      should contain_file('/xlog/path').with({
+        :ensure => 'absent',
+      })
+    end
   end
 
   describe 'package_ensure => absent' do
